"""Constants for pyRejseplan"""

RESOURCE: str = 'https://www.rejseplanen.dk/api/'
COORDINATE_MULTIPLIER: int = 1000000
DATE_FORMAT = '%d.%m.%y'
TIME_FORMAT = '%H:%M'
NS = {'ns0': 'http://hacon.de/hafas/proxy/hafas-proxy'}
